get_asset_info: Returns metadata and information about Tesouro Direto bond...

View source: R/utils.R

get_asset_infoR Documentation

Returns metadata and information about Tesouro Direto bond types

Description

Provides metadata for Brazilian government bond types, including their official names, indexers (e.g., IPCA, SELIC, Fixed rate), payment frequency, and description.

Usage

get_asset_info(asset_codes = NULL)

Arguments

asset_codes

Optional character vector of asset codes (e.g. 'LTN', 'NTN-B'). If 'NULL', returns info for all assets.

Value

A tibble with asset metadata.

Examples

get_asset_info()
get_asset_info("LTN")

GetTDData documentation built on Aug. 29, 2026, 5:07 p.m.