get_td_names: Returns the available asset names at the Tesouro Direto (TD)...

View source: R/utils.R

get_td_namesR Documentation

Returns the available asset names at the Tesouro Direto (TD) website

Description

Returns the available asset names at the Tesouro Direto (TD) website

Usage

get_td_names(online = FALSE)

Arguments

online

Logical. If 'TRUE', attempts to query the Tesouro Direto CDN server for live asset names. Defaults to 'FALSE'.

Value

A character vector of names.

Examples

get_td_names()

GetTDData documentation built on Aug. 29, 2026, 5:07 p.m.