get_yield_curve: Gets the current yield curve

View source: R/gtdd_get_yield_curve.R

get_yield_curveR Documentation

Gets the current yield curve

Description

Downloads and parses information about the current Brazilian yield curve from Anbima.

Usage

get_yield_curve()

get.yield.curve()

Value

A data frame with information about the yield curve.

Examples

## Not run: 
df_yield <- get_yield_curve()
str(df_yield)

## End(Not run)

GetTDData documentation built on June 4, 2026, 5:06 p.m.