Plots the yield curve data frame downloaded using get_yield_curve.
Arguments
- df_yc
A data frame or tibble returned by
get_yield_curve.
Examples
if (FALSE) { # \dontrun{
df_yc <- get_yield_curve()
plot_yield_curve(df_yc)
} # }
Plots the yield curve data frame downloaded using get_yield_curve.
A data frame or tibble returned by get_yield_curve.
if (FALSE) { # \dontrun{
df_yc <- get_yield_curve()
plot_yield_curve(df_yc)
} # }