Returns the available asset names at the Tesouro Direto (TD) website
Source:R/utils.R
get_td_names.RdReturns the available asset names at the Tesouro Direto (TD) website
R/utils.R
get_td_names.RdReturns the available asset names at the Tesouro Direto (TD) website