get_td_names: Returns the available asset names at the Tesouro Direto (TD)...

View source: R/utils.R

get_td_namesR Documentation

Returns the available asset names at the Tesouro Direto (TD) website

Description

Returns the available asset names at the Tesouro Direto (TD) website

Usage

get_td_names()

Value

A character vector of names.

Examples

get_td_names()

GetTDData documentation built on June 4, 2026, 5:06 p.m.