Skip to contents

Downloads and parses information about the current Brazilian yield curve from Anbima.

Usage

get_yield_curve()

get.yield.curve()

Value

A data frame with information about the yield curve.

Examples

if (FALSE) { # \dontrun{
df_yield <- get_yield_curve()
str(df_yield)
} # }