Downloads and parses information about the current Brazilian yield curve from Anbima.
Examples
if (FALSE) { # \dontrun{
df_yield <- get_yield_curve()
str(df_yield)
} # }
Downloads and parses information about the current Brazilian yield curve from Anbima.
if (FALSE) { # \dontrun{
df_yield <- get_yield_curve()
str(df_yield)
} # }