View source: R/gtdd_get_yield_curve.R
| get_yield_curve | R Documentation |
Downloads and parses information about the current Brazilian yield curve from Anbima.
get_yield_curve()
get.yield.curve()
A data frame with information about the yield curve.
## Not run:
df_yield <- get_yield_curve()
str(df_yield)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.