Fetches current prices and yields of Tesouro Direto (TD) assets by downloading the latest daily data available from the website.
Usage
td_get_current(asset_codes = NULL, dl_folder = get_cache_folder())Examples
if (FALSE) { # \dontrun{
df_current <- td_get_current()
head(df_current)
} # }