View source: R/td_get_current.R
| td_get_current | R Documentation |
Fetches current prices and yields of Tesouro Direto (TD) assets by downloading the latest daily data available from the website.
td_get_current(asset_codes = NULL, dl_folder = get_cache_folder())
asset_codes |
A character vector identifying the assets (e.g., 'LTN', 'NTN-B'). If 'NULL', returns all available assets. |
dl_folder |
Path of the folder to save Excel files from Tesouro Direto. Defaults to a session-temporary directory. |
A tibble with current asset prices, yields, and maturity dates.
## Not run:
df_current <- td_get_current()
head(df_current)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.